==> better_mob_drop_no_advancements_version-1.2.2.0-1.13~1.20.4.zip: README.md <==
<div align="center">
    <img align="center" src="https://raw.githubusercontent.com/whwdzg/better_mob_drop/main/pack.png" alt="logo" width="200">
    <h1 align="center">更好的生物掉落（Better_mob_drop）</h1>
    <p align="enter">提供更加合理的生物掉落</p>
    <a href="https://github.com/whwdzg/better_mob_drop/blob/main/README-en.md">English Ver.</a>
    </br>
    <img alt="GitHub Repo stars" src="https://img.shields.io/github/stars/whwdzg/better_mob_drop">
    <img alt="GitHub forks" src="https://img.shields.io/github/forks/whwdzg/better_mob_drop">
    <img alt="GitHub last commit" src="https://img.shields.io/github/last-commit/whwdzg/better_mob_drop">
    <img alt="GitHub contributors" src="https://img.shields.io/github/contributors/whwdzg/better_mob_drop">
    <img alt="GitHub (Pre-)Release Date" src="https://img.shields.io/github/release-date-pre/whwdzg/better_mob_drop">
    <img alt="GitHub release (with filter)" src="https://img.shields.io/github/v/release/whwdzg/better_mob_drop">
    <img alt="GitHub tag (with filter)" src="https://img.shields.io/github/v/tag/whwdzg/better_mob_drop">
    </br>
</div>


最新版本的Minecraft中，Mojang为了所谓保护生物，很多生物都没有对应的掉落物，而这个数据包/模组就是为了解决这个问题的！

现在，各类生物都会直接掉落他们该掉落的！

# Github
[https://github.com/whwdzg/better_mob_drop](https://github.com/whwdzg/better_mob_drop)

# MCMOD
[https://www.mcmod.cn/class/17769.html](https://www.mcmod.cn/class/17769.html)

# Q&A
1. 这个数据包/模组对我的MC有什么更改？
   更好的生物掉落模组/数据包加载后，对应生物都可以合理地掉落对应物品！
2. 那有哪些生物掉落被更改了?
   你可以在游戏中查看进度树，每种生物被击杀时都会点亮对应进度。（仅支持简体中文）

==> better_mob_drop_no_advancements_version-1.2.2.2-1.21.5.zip: README.md <==
<div align="center">
    <img align="center" src="https://raw.githubusercontent.com/whwdzg/better_mob_drop/main/pack.png" alt="logo" width="200">
    <h1 align="center">更好的生物掉落（Better_mob_drop）</h1>
    <p align="enter">提供更加合理的生物掉落</p>
    <a href="https://github.com/whwdzg/better_mob_drop/blob/main/README-en.md">English Ver.</a>
    </br>
    <img alt="GitHub Repo stars" src="https://img.shields.io/github/stars/whwdzg/better_mob_drop">
    <img alt="GitHub forks" src="https://img.shields.io/github/forks/whwdzg/better_mob_drop">
    <img alt="GitHub last commit" src="https://img.shields.io/github/last-commit/whwdzg/better_mob_drop">
    <img alt="GitHub contributors" src="https://img.shields.io/github/contributors/whwdzg/better_mob_drop">
    <img alt="GitHub (Pre-)Release Date" src="https://img.shields.io/github/release-date-pre/whwdzg/better_mob_drop">
    <img alt="GitHub release (with filter)" src="https://img.shields.io/github/v/release/whwdzg/better_mob_drop">
    <img alt="GitHub tag (with filter)" src="https://img.shields.io/github/v/tag/whwdzg/better_mob_drop">
    </br>
</div>


最新版本的Minecraft中，Mojang为了所谓保护生物，很多生物都没有对应的掉落物，而这个数据包/模组就是为了解决这个问题的！

现在，各类生物都会直接掉落他们该掉落的！

# Modrinth
[https://modrinth.com/datapack/better_mob_drop](https://modrinth.com/datapack/better_mob_drop)

# MCMOD
[https://www.mcmod.cn/class/17769.html](https://www.mcmod.cn/class/17769.html)

# Q&A
1. 这个数据包/模组对我的MC有什么更改？
   更好的生物掉落模组/数据包加载后，对应生物都可以合理地掉落对应物品！
2. 那有哪些生物掉落被更改了?
   你可以在游戏中查看进度树，每种生物被击杀时都会点亮对应进度。（仅支持简体中文）
